#!/bin/sh
#
# Patch & build sources for ROX
# (c) Andrew Flegg 2004. Released under the Artistic Licence

# -- Define how to build this application ---------------------
#
UNPACK="tar xzf gaim-0.77.tar.gz"
SRCDIR="gaim-0.77"
APPNAME="gaim"
# =============================================================

# -- Platform passed in by AppRun...
#
PLATFORM=$1
[ -z "$PLATFORM" ] && PLATFORM=noarch

# -- Unpack the source...
#
THIS_DIR=`dirname "$0"`
THIS_DIR=`cd "$THIS_DIR"; pwd`
APP_DIR=`cd "$THIS_DIR/.."; pwd`

cd "$THIS_DIR"
$UNPACK
cd $SRCDIR

# -- Apply patches...
#
for i in "$THIS_DIR/patches/"*.patch; do
    patch -p1 <"$i"
done

# -- Configure, make and install...
#
mkdir -p "../$PLATFORM"
./configure --prefix="../$PLATFORM" || exit 1
make || exit 1
make install || exit 1

find . -name "$PLATFORM" -type d -exec cp -av {} ../ \;
mv "$THIS_DIR/$PLATFORM" "$APP_DIR/$PLATFORM" || exit 1

(find "$APP_DIR/$PLATFORM" -type f -perm 0755 -exec strip {} \;) 2>/dev/null

noarch() {
    DEST=""
    FROM="$1"
    TO=`basename "$FROM"`
    TODIR=`dirname "$FROM"`
    [ "$TO" = "$APPNAME" ] && TO=`basename "$TODIR"`

    f="$FROM"
    while ( [ "$f" != "." ] ) ; do
        f=`dirname "$f"`
	DEST="../$DEST"
    done

    echo "../$PLATFORM/$FROM -> ${DEST}${TO}"
    if [ -d "$APP_DIR/$TO" ] ; then
        rm -rf "$APP_DIR/$PLATFORM/$FROM"
    else
        mv "$APP_DIR/$PLATFORM/$FROM" "$APP_DIR/$TO"
    fi

    ln -snf "${DEST}${TO}" "../$PLATFORM/$FROM"
    return
}
    

# -- Tidy up (application specific)...
#
mkdir -p "$APP_DIR/Help"
cd "$SRCDIR"
mv -f ChangeLog AUTHORS COPYRIGHT VERSION NEWS PROGRAMMING_NOTES README \
      doc/{CREDITS,FAQ,*.txt} \
      "$APP_DIR/Help/"
cd "$THIS_DIR"

noarch include
mv "../$PLATFORM/man/man1/gaim"* "$APP_DIR/Help/"
mv "../$PLATFORM/share/man/man3/"* "$APP_DIR/Help/"
rm -rf "../$PLATFORM/man"
rm -rf "../$PLATFORM/share/man"
rm -rf "../$PLATFORM/share/applications"
rm -rf "../$PLATFORM/share/perl5"

noarch share/locale
noarch share/pixmaps/gaim
mv "../$PLATFORM/share/pixmaps/gaim.png" "$APP_DIR/.DirIcon"

noarch share/sounds/gaim

# -- Clear out the source...
#
cd "$THIS_DIR"
rm -rf "$SRCDIR"
